@@ -1,4 +1,4 @@
-# $Id: Lexed.pm,v 1.14 2006/08/22 13:09:14 rousse Exp $
+# $Id: Lexed.pm,v 1.5 2004/11/25 15:47:01 rousse Exp $
 
 package Dict::Lexed;
 
@@ -8,7 +8,7 @@ Dict::Lexed - Lexed wrapper
 
 =head1 VERSION
 
-Version 0.2.2
+Version 0.1
 
 =head1 DESCRIPTION
 
@@ -33,10 +33,7 @@ use IO::Handle;
 use strict;
 use warnings;
 
-our $VERSION = '0.2.2';
-
-my $unknown   = "\001";
-my $delimiter = "\002";
+our $VERSION = '0.1';
 
 =head1 Class methods
 
@@ -67,7 +64,7 @@ sub create_dict {
     my $command = "lexed $options build $mode_options 2>/dev/null";
     open(LEXED, "| $command") or die "Can't run $command: $!";
     foreach my $word (@{$wordlist}) {
-        print LEXED $word . "\t" . $word . "\n";
+	print LEXED $word . "\t" . $word . "\n";
     }
     close(LEXED);
 }
@@ -97,12 +94,12 @@ specific consultation options passed to lexed
 sub new {
     my ($class, $options, $mode_options) = @_;
     my $self = bless {
-        _in  => IO::Handle->new(),
-        _out => IO::Handle->new()
+	_in  => IO::Handle->new(),
+	_out => IO::Handle->new()
     }, $class;
     $options ||= "";
     $mode_options ||= "";
-    my $command = "lexed $options consult -f '' '$delimiter' '\n' '$unknown' $mode_options 2>/dev/null";
+    my $command = "lexed $options consult $mode_options 2>/dev/null";
     open2($self->{_out}, $self->{_in}, "$command") or die "Can't run $command: $!";
     return $self;
 }
@@ -116,44 +113,12 @@ sub DESTROY {
 
 =head1 Methods
 
-
-=head2 $dict->check(I<$word>)
-
-Check the dictionnary for exact match of word I<$word>.
-Returns a true value if word is present in the dictionnary, false otherwise.
-
-=cut
-
-sub check {
-    my ($self, $word) = @_;
-
-    my @query = $self->query($word);
-    return (@query) ?
-    grep { /^\Q$word\E$/ } @query :
-    0;
-}
-
-=head2 $dict->suggest(I<$word>)
-
-Check the dictionnary for approximate match of word I<$word>.
-Returns a list of approximated words from the dictionnary, according to
-parameters passed when creating the object.
-
-=cut
-
-sub suggest {
-    my ($self, $word) = @_;
-
-    my @query = $self->query($word);
-    return (@query) ?
-        grep { ! /^$word$/ } @query :
-        ();
-}
-
 =head2 $dict->query(I<$word>)
 
-Query the dictionnary for word I<$word>.
-Returns the raw result of the query, as a list of words.
+Queries lexed about the word I<$word>.
+Returns lexed result as a list of words;
+
+This is actually a low-level method, not intented for direct use.
 
 =cut
 
@@ -164,10 +129,40 @@ sub query {
     print $in $word . "\n";
     my $line = <$out>;
     chomp $line;
+    
+    return split(/\|/, $line);
+}
 
-    return $line eq $unknown ?
-        () :
-        split(/$delimiter/, $line);
+=head2 $dict->check(I<$word>)
+
+Queries lexed for presence/absence of a given word.
+Returns a true value if word I<$word> is present in the dictionnary, false otherwise.
+
+=cut
+
+sub check {
+    my ($self, $word) = @_;
+
+    my @query = $self->query($word);
+    return ($query[0] eq '<unknown>') ?
+	0 :
+	grep { /^$word$/ } @query;
+}
+
+=head2 $dict->suggest(I<$word>)
+
+Queries lexed for approximate match of a given word.
+Returns a list of words close to word I<$word>, according to parameters passed when creating the object.
+
+=cut
+
+sub suggest {
+    my ($self, $word) = @_;
+
+    my @query = $self->query($word);
+    return ($query[0] eq '<unknown>') ?
+	() :
+	grep { ! /^$word$/ } @query;
 }
 
 =head1 COPYRIGHT AND LICENSE
